@@ -33,8 +33,7 @@ class APIHandler(object):
         self.url = url
         self.retry_config = retry_config
 
-    @property
-    def session(self):
+    def get_session(self):
         session = requests.Session()
         if self.retry_config:
             retry = Retry(
@@ -84,7 +83,7 @@ class APIHandler(object):
                 secret = credentials.get("secret")
         else:
             raise Exception("Required: either token/secret, username/password, or saved ~/.freedom_credentials file")
-        
+
         api = cls(token, secret, url=url, **kwargs)
         if default_api is None:
             set_default_api(api)
@@ -103,35 +102,39 @@ class APIHandler(object):
                 "mc_token": self.token,
                 "mc_secret": self.secret,
             }
-   
+
         url = self.url.strip("/") + "/" + path.strip("/")
         if method == "GET":
-            r = self.session.get(
-                url,
-                headers=auth_headers,
-                params=params
-            )
+            with self.get_session() as session:
+                r = session.get(
+                    url,
+                    headers=auth_headers,
+                    params=params
+                )
         elif method == "POST":
-            r = self.session.post(
-                url,
-                headers=auth_headers,
-                params=params,
-                json=data
-            )
+            with self.get_session() as session:
+                r = session.post(
+                    url,
+                    headers=auth_headers,
+                    params=params,
+                    json=data
+                )
         elif method == "PUT":
-            r = self.session.put(
-                url,
-                headers=auth_headers,
-                params=params,
-                json=data
-            )
+            with self.get_session() as session:
+                r = session.put(
+                    url,
+                    headers=auth_headers,
+                    params=params,
+                    json=data
+                )
         elif method == "DELETE":
-            r = self.session.delete(
-                url,
-                headers=auth_headers,
-                params=params,
-            )
-        
+            with self.get_session() as session:
+                r = session.delete(
+                    url,
+                    headers=auth_headers,
+                    params=params,
+                )
+
         if r.status_code >= 400:
             raise APIError.from_response(r)
 
@@ -180,4 +183,4 @@ class NotFoundError(APIError):
 
 
 class ServerError(APIError):
-    ERROR = "Server Error"
\ No newline at end of file
+    ERROR = "Server Error"
